@@ -13,6 +13,8 @@
 # limitations under the License.
 
 import logging
+
+from ibm_watson_machine_learning.messages.messages import Messages
 from ibm_watson_machine_learning.utils import version
 
 #from ibm_watson_machine_learning.learning_system import LearningSystem
@@ -115,6 +117,10 @@ class APIClient:
         os.environ['WSD_PLATFORM'] = 'False'
         if wml_credentials is None:
             raise NoWMLCredentialsProvided()
+        if 'url' not in self.wml_credentials:
+            raise WMLClientError(Messages.get_message(message_id="url_not_provided"))
+        if not self.wml_credentials['url'].startswith('https://'):
+            raise WMLClientError(Messages.get_message(message_id="invalid_url"))
         if self.wml_credentials['url'][-1] == "/":
             self.wml_credentials['url'] = self.wml_credentials['url'].rstrip('/')
 
@@ -128,16 +134,19 @@ class APIClient:
                 self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
                 self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
             else:
-                raise WMLClientError("Provided 'url' is not valid")
+                raise WMLClientError(Messages.get_message(message_id="invalid_cloud_scenario_url"))
 
             if not self._is_IAM():
-                raise WMLClientError('apikey for IAM token is not provided in credentials for the client')
+                raise WMLClientError(Messages.get_message(message_id="apikey_not_provided"))
         else:
             if 'icp' == wml_credentials[u'instance_id'].lower() or 'openshift' == wml_credentials[
                 u'instance_id'].lower() or 'wml_local' == wml_credentials[u'instance_id'].lower():
                 self.ICP = True
                 os.environ["DEPLOYMENT_PLATFORM"] = "private"
                 ##Condition for CAMS related changes to take effect (Might change)
+                if 'version' not in wml_credentials:
+                    raise WMLClientError(Messages.get_message(self.__wml_local_supported_version_list, message_id="version_not_provided"))
+
                 if 'version' in wml_credentials.keys() and (
                         '2.0.1' == wml_credentials[u'version'].lower() or '2.5.0' == wml_credentials[
                     u'version'].lower() or
@@ -152,7 +161,7 @@ class APIClient:
                                 u'version'].lower()):
                         url_port = wml_credentials[u'url'].split(':')[-1]
                         if not url_port.isdigit():
-                            raise WMLClientError("It is mandatory to have port number as part of url for wml_local.")
+                            raise WMLClientError(Messages.get_message(message_id="no_port_number_for_wml_local"))
 
                     if '3.0.0' == wml_credentials[u'version'].lower() or \
                             '3.0.1' == wml_credentials[u'version'].lower() or \
@@ -174,10 +183,9 @@ class APIClient:
                 else:
                     if 'version' in wml_credentials.keys() and \
                             wml_credentials[u'version'].lower() not in self.__wml_local_supported_version_list:
-                        raise WMLClientError(
-                            "Invalid value for 'version' provided in wml_credentials. Please check the wml_credentials provided." +
-                            "Supported value for version field are: " + ', '.join(
-                                self.__wml_local_supported_version_list))
+                        raise WMLClientError(Messages.get_message(
+                            ', '.join(self.__wml_local_supported_version_list),
+                            message_id="invalid_version"))
 
                     self.CAMS = False
             else:
@@ -191,13 +199,15 @@ class APIClient:
                     if ('wsd_local' == wml_credentials[u'instance_id'].lower()) and \
                             'version' in wml_credentials.keys() and \
                             wml_credentials[u'version'].lower() not in self.__wsd_supported_version_list:
-                        raise WMLClientError(
-                            "Invalid value for 'version' provided in wml_credentials. Please check the wml_credentials provided." +
-                            "Supported value for version field are: " + ', '.join(self.__wsd_supported_version_list))
+                        raise WMLClientError(Messages.get_message(
+                            ', '.join(self.__wsd_supported_version_list),
+                            message_id="invalid_version"))
 
                     if 'instance_id' in wml_credentials.keys():
-                        raise WMLClientError(
-                            "Provided credentials are invalid. 'instance_id' should not be used in cloud scenario. Please check the wml_credentials provided.")
+                        if wml_credentials['url'] in self.PLATFORM_URLS_MAP:
+                            raise WMLClientError(Messages.get_message(message_id="instance_id_in_cloud_scenario"))
+                        else:
+                            raise WMLClientError(Messages.get_message(message_id="invalid_instance_id"))
 
                     self.ICP = False
                     self.CAMS = False
@@ -232,36 +242,24 @@ class APIClient:
                                 # If v1 lite converted to v2 plan, tags : ["created_in_v1_plan"]
 
                                 if not self._is_IAM():
-                                    raise WMLClientError('apikey for IAM token is not provided in credentials for '
-                                                         'the client.')
+                                    raise WMLClientError(Messages.get_message(message_id="apikey_not_provided"))
 
                                 if wml_credentials[u'url'] in self.PLATFORM_URLS_MAP.keys():
                                     self.PLATFORM_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
                                     self.CAMS_URL = self.PLATFORM_URLS_MAP[wml_credentials[u'url']]
                                 else:
-                                    raise WMLClientError("No 'url' provided")
+                                    raise WMLClientError(Messages.get_message(message_id="url_not_provided"))
 
                                 if self.CLOUD_PLATFORM_SPACES:
-                                    print("Note that if you are using any of v2 instance plans, then 'instance_id' is"
-                                          " not required to be provided here. It will be picked up from space when "
-                                          "client.set.default_space(space_id) is called ")
+                                    print(Messages.get_message(message_id="instance_id_is_not_required_for_v2_plans"))
 
                             if not self.CLOUD_PLATFORM_SPACES:
                                 self.CLOUD_BETA_FLOW = True
-                                print("NOTE!! DEPRECATED!! Creating assets using this flow(v4 beta) is deprecated"
-                                      " starting Sep 1st, 2020 and will be discontinued at the end of the migration period. "
-                                      "Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' "
-                                      "for the migration process to be able to access new features")
+                                print(Messages.get_message(message_id="creating_assets_using_v4_beta_flow_is_deprecated"))
                     elif response_get_instance.status_code == 404:
-                        raise WMLClientError("instance_id not found. Note that if you are using "
-                                             "any of new instance plans [], then 'instance_id' is not required "
-                                             "to be provided here. It will be picked up from space when "
-                                             "client.set.default_space(space_id) is called ")
+                        raise WMLClientError(Messages.get_message(message_id="instance_id_not_found"))
                     elif response_get_instance.status_code == 401:
-                        raise WMLClientError("Not authorized to access the instance_id  Note that if you are using "
-                                             "any of new instance plans [], then 'instance_id' is not required "
-                                             "to be provided here. It will be picked up from space when "
-                                             "client.set.default_space(space_id) is called")
+                        raise WMLClientError(Messages.get_message(message_id="not_authorized_to_access_the_instance_id"))
                     else:
                         # if someone is using beta flow and using instance api key
                         response_get_instance_v1 = requests.get(
@@ -271,16 +269,12 @@ class APIClient:
                         )
 
                         if response_get_instance_v1.status_code != 200:
-                            raise WMLClientError("Failed to get instance details. Note that if you are using "
-                                                 "any of new instance plans [], then 'instance_id' is not required "
-                                                 "to be provided here. It will be picked up from space when "
-                                                 "client.set.default_space(space_id) is called.\n  Error:" + response_get_instance.text)
+                            raise WMLClientError(Messages.get_message(
+                                response_get_instance.text,
+                                message_id="failed_to_get_instance_details"))
 
                         self.CLOUD_BETA_FLOW = True
-                        print("NOTE!! DEPRECATED!! Creating assets using this flow(v4 beta) is deprecated"
-                              " starting Sep 1st, 2020 and will be discontinued at the end of the migration period. "
-                              "Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' "
-                              "for the migration process to be able to access new features")
+                        print(Messages.get_message(message_id="creating_assets_using_v4_beta_flow_is_deprecated"))
             if "token" in wml_credentials:
                 self.proceed = True
             else:
@@ -289,14 +283,13 @@ class APIClient:
         if 'instance_id' in wml_credentials.keys() and \
                 (wml_credentials['instance_id'].lower() not in self.__predefined_instance_type_list) and \
                 'version' in wml_credentials.keys():
-            raise WMLClientError("Provided credentials are invalid. 'instance_id' and 'version' keys provided are not correct. Please check the wml_credentials provided."  )
+            raise WMLClientError(Messages.get_message(message_id="provided_credentials_are_invalid"))
 
         self.project_id = project_id
         self.wml_token = None
 
         if not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES and not self.CLOUD_BETA_FLOW:
-            raise WMLClientError("This client is not supported in this release. Refer to the documentation at "
-                                 "http://ibm-wml-api-pyclient.mybluemix.net to know what releases are supported")
+            raise WMLClientError(Messages.get_message(message_id="client_is_not_supported_in_this_release"))
 
         # if not self.ICP and not self.ICP_30 and not self.WSD:
         if not self.WSD and not self.CLOUD_PLATFORM_SPACES and not self.ICP_PLATFORM_SPACES:
@@ -309,13 +302,9 @@ class APIClient:
             import sys
             if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
                 if self.CLOUD_PLATFORM_SPACES:
-                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Apr 8th, 2021. "
-                          "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create new assets using this client. "
-                          "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
+                    print(Messages.get_message(message_id="python_3_6_framework_is_deprecated"))
                 elif self.ICP_PLATFORM_SPACES:
-                    print("DEPRECATED!! The Python 3.6 framework is deprecated and will be removed from a future release. "
-                    "We recommend you migrate your assets and use a Python 3.7 framework instead. "
-                    "For details, see https://www.ibm.com/support/knowledgecenter/SSQNUZ_current/wsj/analyze-data/pm_service_supported_frameworks.html")
+                    print(Messages.get_message(message_id="python_3_6_framework_is_deprecated_cp4d"))
 
             self.service_instance = ServiceInstanceNewPlan(self)
             self.volumes = Volume(self)
@@ -386,18 +375,18 @@ class APIClient:
             self.connections = Connections(self)
             self.experiments = Experiments(self)
 
-        self._logger.info(u'Client successfully initialized')
+        self._logger.info(Messages.get_message(message_id="client_successfully_initialized"))
         self.version = version()
 
     def _check_if_either_is_set(self):
         if self.CAMS or self.CLOUD_PLATFORM_SPACES:
             if self.default_space_id is None and self.default_project_id is None:
-                raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
+                raise WMLClientError(Messages.get_message(message_id="it_is_mandatory_to_set_the_space_project_id"))
 
     def _check_if_space_is_set(self):
         if self.CAMS or self.CLOUD_PLATFORM_SPACES:
             if self.default_space_id is None:
-                raise WMLClientError("It is mandatory to set the space. Use client.set.default_space(<SPACE_UID>) to proceed.")
+                raise WMLClientError(Messages.get_message(message_id="it_is_mandatory_to_set_the_space_id"))
 
     def _params(self, skip_space_project_chk=False, skip_for_create=False):
         params = {}
@@ -412,14 +401,13 @@ class APIClient:
                 else:
                     # For system software/hardware specs
                     if skip_space_project_chk is False:
-                        raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
+                        raise WMLClientError(Messages.get_message(message_id="it_is_mandatory_to_set_the_space_project_id"))
 
         if self.WSD:
             if self.default_project_id is not None:
                 params.update({'project_id': self.default_project_id})
             else:
-                raise WMLClientError(
-                    "It is mandatory to set the project id. Use client.set.default_project(<PROJECT_UID>) to proceed.")
+                raise WMLClientError(Messages.get_message(message_id="it_is_mandatory_to_set_the_project_id"))
 
         if self.project_type == 'local_git_storage':
             params.update({'userfs': 'true'})
@@ -482,11 +470,11 @@ class APIClient:
             if (self.wml_credentials['apikey'] != ''):
                 return True
             else:
-                raise WMLClientError('apikey value cannot be \'\'. Pass a valid apikey for IAM token.')
+                raise WMLClientError(Messages.get_message(message_id="apikey_value_cannot_be_empty"))
         elif('token' in self.wml_credentials.keys()):
             if (self.wml_credentials['token'] != ''):
                 return True
             else:
-                raise WMLClientError('token value cannot be \'\'. Pass a valid token for IAM token.')
+                raise WMLClientError(Messages.get_message(message_id="token_value_cannot_be_empty"))
         else:
             return False
