@@ -21,6 +21,7 @@ from warnings import warn
 from contextlib import redirect_stdout
 
 from pandas import DataFrame
+import requests
 
 from ..experiment import AutoAI
 from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto_ai_model_to_publish_normal_scenario,
@@ -28,7 +29,7 @@ from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto
                                   prepare_auto_ai_model_to_publish_notebook_normal_scenario,
                                   download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn)
 from ..utils.deployment.errors import (WrongDeploymnetType, ModelTypeNotSupported, NotAutoAIExperiment,
-                                       DeploymentNotSupported, MissingSpace, ModelStoringFailed)
+                                       DeploymentNotSupported, MissingSpace, ModelPromotionFailed)
 from ..wml_client_error import ApiRequestFailure
 from ..workspace import WorkSpace
 
@@ -560,6 +561,39 @@ class BaseDeployment(ABC):
         """Protected method to create a deployment."""
         pass
 
+    def _promote_model(self,
+                       model_id: str,
+                       project_id: str,
+                       space_id: str):
+        """
+        Protected method to promote a model from project to deployment space.
+        Returns id of promoted model.
+        """
+
+        promote_payload = {"spaceId": space_id,
+                           "projectId": project_id,
+                           "assetType": "wml_model",
+                           "assetDescription": "Model promoted by ibm_wml client"}
+        promote_href = self._source_workspace.wml_client.service_instance._href_definitions.promote_asset_href(model_id)
+
+        response = requests.post(
+            promote_href,
+            headers=self._source_workspace.wml_client._get_headers(),
+            json=promote_payload,
+            verify=False
+        )
+        promotion_details = self._source_workspace.wml_client.repository._handle_response(200, u'promote model asset', response)
+
+        try:
+            promoted_model_id = promotion_details['promotedAsset']['asset_id']
+        except KeyError as key_err:
+            raise ModelPromotionFailed(project_id, space_id, promotion_details, reason=key_err)
+
+        return promoted_model_id
+
+
+
+
     def _publish_model(self,
                        pipeline_model: Union['Pipeline', str],
                        meta_props: Dict) -> str:
@@ -578,11 +612,26 @@ class BaseDeployment(ABC):
         -------
         String with asset_id.
         """
-        published_model_details = self._target_workspace.wml_client.repository.store_model(
-            model=pipeline_model,
-            meta_props=meta_props)
 
-        asset_id = self._target_workspace.wml_client.repository.get_model_uid(published_model_details)
+        # TODO: Remove `if ICP_40` when promotion will be available for cloud
+        # Note: publish model to project and then promote to space
+        if self._source_workspace.wml_client.ICP_40 and self._source_workspace.project_id and self._source_workspace.project_id in str(meta_props):
+            published_model_details = self._source_workspace.wml_client.repository.store_model(
+                model=pipeline_model,
+                meta_props=meta_props)
+
+            project_asset_id = self._source_workspace.wml_client.repository.get_model_uid(published_model_details)
+
+            asset_id = self._promote_model(model_id=project_asset_id,
+                                           project_id=self._source_workspace.project_id,
+                                           space_id=self._target_workspace.space_id)
+
+        else:
+            published_model_details = self._target_workspace.wml_client.repository.store_model(
+                model=pipeline_model,
+                meta_props=meta_props)
+
+            asset_id = self._target_workspace.wml_client.repository.get_model_uid(published_model_details)
 
         print(f"Published model uid: {asset_id}")
         return asset_id
