@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import io
+import os
 import time
 from typing import TYPE_CHECKING, Any, Dict, Union, List, Optional
 
@@ -480,7 +481,8 @@ class Batch(BaseDeployment):
                     if conn.type == DataConnectionTypes.S3:
                         conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
 
-                    elif conn.type == DataConnectionTypes.CA and conn._check_if_connection_asset_is_s3():
+                    elif (conn.type == DataConnectionTypes.CA and
+                          (os.environ.get('USER_ACCESS_TOKEN') is None and conn._check_if_connection_asset_is_s3())):
                         conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
 
                 return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
