@@ -18,7 +18,8 @@ from typing import List, Union
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics,\
-    Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass)
+    Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass, ClassificationAlgorithmsCP4D,
+    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
     TSNotSupported, ParamOutOfRange
@@ -68,9 +69,12 @@ class AutoAI(BaseExperiment):
     >>>         space_id="...")
     """
     # note: initialization of AutoAI enums as class properties
+
+    # note: Enums with estimators can be overwritten  in _init based on environment type (CPD or Cloud)
     ClassificationAlgorithms = ClassificationAlgorithms
     RegressionAlgorithms = RegressionAlgorithms
     ForecastingAlgorithms = ForecastingAlgorithms
+    # end note
     TShirtSize = TShirtSize
     PredictionType = PredictionType
     Metrics = Metrics
@@ -78,7 +82,6 @@ class AutoAI(BaseExperiment):
     DataConnectionTypes = DataConnectionTypes
     PipelineTypes = PipelineTypes
 
-
     def __init__(self,
                  wml_credentials: Union[dict, 'WorkSpace'] = None,
                  project_id: str = None,
@@ -103,6 +106,8 @@ class AutoAI(BaseExperiment):
             self.runs = AutoPipelinesRuns(engine=WMLEngine(self._workspace))
             self.runs._workspace = self._workspace
 
+        self._init_estimator_enums()
+
         self._20_class_limit_removal_test = False
         # --- end note
 
@@ -163,6 +168,7 @@ class AutoAI(BaseExperiment):
                   positive_label: str = None,
                   data_join_only: bool = False,
                   drop_duplicates: bool = True,
+                  # fairness_info: dict = None, #TODO: Uncomment to add fairness support
                   text_processing: bool = None,
                   word2vec_feature_number: int = None,
                   daub_give_priority_to_runtime: float = None,
@@ -286,6 +292,7 @@ class AutoAI(BaseExperiment):
         >>> from ibm_watson_machine_learning.experiment import AutoAI
         >>> experiment = AutoAI(...)
         >>>
+        >>>
         >>> optimizer = experiment.optimizer(
         >>>        name="name of the optimizer.",
         >>>        prediction_type=AutoAI.PredictionType.BINARY,
@@ -309,6 +316,24 @@ class AutoAI(BaseExperiment):
         >>>    )
         """
 
+        # # TODO: Pass the fairness info description and example when adding fairness support and
+        #
+        # """
+        # fairness_info: dict, optional
+        #     Dictionary that  specifies metadata needed for measuring fairness. It contains two key values:
+        #     favorable_labels and protected_attributes. The favorable_labels attribute indicates that when the class
+        #     column contains one of the value from list, that is considered a positive outcome.
+        #     A protected attribute is a feature that partitions the population into groups whose outcome should have parity.
+        #     If passed fairness metric will be calculated.
+        # >>> fairness_info = {
+        # >>>        "protected_attributes": [
+        # >>>            {"feature": "Sex", "privileged_groups": ['female']},
+        # >>>             {"feature": "Age", "privileged_groups": [[20, 40], [60, 90]]}
+        # >>>        ],
+        # >>>        "favorable_labels": ["No Risk"]
+        # >>>    }
+        # """
+
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.0') or \
@@ -340,7 +365,8 @@ class AutoAI(BaseExperiment):
             include_only_estimators=include_only_estimators,
             cognito_transform_names=cognito_transform_names,
             scoring=scoring,
-            t_shirt_size=kwargs.get("t_shirt_size", TShirtSize.M)
+            t_shirt_size=kwargs.get("t_shirt_size", TShirtSize.M),
+            is_cpd=self._workspace.wml_client.ICP
         )
 
         if daub_give_priority_to_runtime is not None:
@@ -438,7 +464,18 @@ class AutoAI(BaseExperiment):
                 notebooks=kwargs.get('notebooks', True),
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
                 obm_pod_version=kwargs.get('obm_pod_version', None),
+                # fairness_info=fairness_info, #TODO: Uncomment to add fairness support
                 **reduced_kwargs
             )
             optimizer._workspace = self._workspace
             return optimizer
+
+    def _init_estimator_enums(self):
+        if self._workspace and self._workspace.wml_client.ICP:
+            self.ClassificationAlgorithms = ClassificationAlgorithmsCP4D
+            self.RegressionAlgorithms = RegressionAlgorithmsCP4D
+            self.ForecastingAlgorithms = ForecastingAlgorithmsCP4D
+        else:
+            self.ClassificationAlgorithms = ClassificationAlgorithms
+            self.RegressionAlgorithms = RegressionAlgorithms
+            self.ForecastingAlgorithms = ForecastingAlgorithms
