@@ -16,6 +16,7 @@ from typing import TYPE_CHECKING, List, Dict, Tuple
 
 from pandas import DataFrame, MultiIndex
 import json
+import os
 from time import sleep
 import warnings
 import logging
@@ -132,6 +133,13 @@ class WMLEngine(BaseEngine):
 
         # end of section
 
+        # pass fairness info if not CPD
+        if not self._wml_client.ICP:
+            if self._auto_pipelines_parameters.get('fairness_info') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'fairness_info'] = self._auto_pipelines_parameters.get('fairness_info')
+        # end of section
 
         if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
@@ -812,7 +820,8 @@ class WMLEngine(BaseEngine):
         # note: recreation of s3 creds from connection asset
         results_reference = DataConnection._from_dict(run_params['entity']['results_reference'])
         results_reference._wml_client = self._wml_client
-        results_reference._check_if_connection_asset_is_s3()
+        if os.environ.get('USER_ACCESS_TOKEN') is None:
+            results_reference._check_if_connection_asset_is_s3()
         run_params['entity']['results_reference'] = results_reference._to_dict()
         # --- end note
 
