@@ -18,6 +18,7 @@ __all__ = [
 
 import io
 import json
+import os
 
 from abc import ABC, abstractmethod
 from typing import Union, Tuple, TYPE_CHECKING
@@ -158,7 +159,7 @@ class BaseDataConnection(ABC):
                 json_content = json.loads(buffer.getvalue().decode('utf-8'))
 
         elif self.type == DataConnectionTypes.CA:
-            if self._check_if_connection_asset_is_s3():
+            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
