@@ -346,7 +346,8 @@ class DataConnection(BaseDataConnection):
              with_holdout_split: bool = False,
              csv_separator: str = ',',
              excel_sheet: Union[str, int] = 0,
-             encoding: Optional[str] = 'utf-8') -> Union['DataFrame', Tuple['DataFrame', 'DataFrame']]:
+             encoding: Optional[str] = 'utf-8',
+             **kwargs) -> Union['DataFrame', Tuple['DataFrame', 'DataFrame']]:
         """
         Download dataset stored in remote data storage.
 
@@ -426,7 +427,7 @@ class DataConnection(BaseDataConnection):
                 raise NotImplementedError("Multiple files for CP4D / WML Server is not yet supported.")
 
             try:
-                if self._check_if_connection_asset_is_s3():
+                if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
                     cos_client = self._init_cos_client()
                     data = self._download_data_from_cos(cos_client=cos_client)
                 else:
@@ -448,6 +449,7 @@ class DataConnection(BaseDataConnection):
                     wml_client=self._wml_client,
                     params=self.auto_pipeline_params,
                     data_location=data_location,
+                    experiment_metadata=kwargs.get('experiment_metadata')
                 )
 
                 data = flight_service.read()
@@ -461,7 +463,7 @@ class DataConnection(BaseDataConnection):
 
         elif self.type == DataConnectionTypes.CA:
 
-            if self._check_if_connection_asset_is_s3():
+            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
@@ -487,6 +489,7 @@ class DataConnection(BaseDataConnection):
                         data_location={'location': self.location.to_dict(),
                                        'type': self.type,
                                        "connection": self.connection.to_dict()},
+                        experiment_metadata=kwargs.get('experiment_metadata')
                     )
 
                     data = flight_service.read()
@@ -539,7 +542,7 @@ class DataConnection(BaseDataConnection):
 
         return data
 
-    def write(self, data: Union[str, 'DataFrame'], remote_name: str = None) -> None:
+    def write(self, data: Union[str, 'DataFrame'], remote_name: str = None, **kwargs) -> None:
         """
         Upload file to a remote data storage.
 
@@ -577,7 +580,7 @@ class DataConnection(BaseDataConnection):
                 raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
 
         elif self.type == DataConnectionTypes.CA:
-            if self._check_if_connection_asset_is_s3():
+            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
                 cos_resource_client = self._init_cos_client()
                 if isinstance(data, str):
                     with open(data, "rb") as file_data:
@@ -606,6 +609,7 @@ class DataConnection(BaseDataConnection):
                     data_location={'location': self.location.to_dict(),
                                    'type': self.type,
                                    "connection": self.connection.to_dict()},
+                    experiment_metadata=kwargs.get('experiment_metadata')
                 )
 
                 if isinstance(data, str):
