@@ -55,11 +55,13 @@ class FlightService:
                  wml_client: 'APIClient',
                  params: dict,
                  n_batches: Optional[int] = 1,
-                 data_location: dict = None,) -> None:
+                 data_location: dict = None,
+                 experiment_metadata: dict = None) -> None:
         self.wml_client = wml_client
         self.params = params
         self.n_batches = n_batches
         self.data_source_type = None
+        self.experiment_metadata = experiment_metadata
 
         self.data_location = data_location
 
@@ -309,7 +311,12 @@ class FlightService:
 
         # note: WS scenario
         if self.wml_client is None:
-            command['project_id'] = os.environ.get('PROJECT_ID')
+            project_id = os.environ.get('PROJECT_ID')
+            if project_id is None:
+                command['project_id'] = self.experiment_metadata.get('project_id')
+
+            else:
+                command['project_id'] = project_id
 
         else:
             if self.wml_client.default_space_id is not None:
