@@ -153,6 +153,8 @@ VOLUME_ID = u'{}/zen-data/v3/service_instances/{}'
 VOLUME_SERVICE = u'{}/zen-data/v1/volumes/volume_services/{}'
 VOLUME_SERVICE_FILE_UPLOAD = u'{}/zen-volumes/{}/v1/volumes/files/'
 
+PROMOTE_ASSET = u'{}/api/rest/catalogs/assets/{}/promote'
+
 def is_url(s):
     res = re.match('https?:\/\/.+', s)
     return res is not None
@@ -476,6 +478,9 @@ class HrefDefinitions:
     def volume_upload_href(self, volume_name):
         return VOLUME_SERVICE_FILE_UPLOAD.format(self._wml_credentials['url'], volume_name)
 
+    def promote_asset_href(self, asset_id):
+        return PROMOTE_ASSET.format(self._wml_credentials['url'], asset_id)
+
     # def get_envs_href(self):
     #     return DEPLOYMENT_ENVS_HREF_PATTERN.format(self._wml_credentials['url'])
     #
