@@ -17,7 +17,7 @@ class Import(WMLResource):
     def start(self, file_path=None, space_id=None, project_id=None):
         """
             Start the import. Either space_id or project_id has to be provided and is mandatory. Note that
-            on IBM Cloud Pak® for Data for Data 3.5, import into non-empty space/project is not supported
+            on IBM Cloud Pak® for Data 3.5, import into non-empty space/project is not supported
 
            **Parameters**
 
