@@ -271,7 +271,7 @@ class ServiceInstance:
         if response.status_code == 200:
             token = response.json().get(u'access_token')
         else:
-            raise ApiRequestFailure(u'Error during getting IAM Token.', response)
+            raise ApiRequestFailure(u'Error getting IAM Token.', response)
         return token
 
     def _create_zen_token(self):
