@@ -32,7 +32,6 @@ class ServiceInstanceNewPlan:
         self._client = client
         self._wml_credentials = client.wml_credentials
         self._expiration_datetime = None
-        self._is_iam_token = None
 
         if self._client.ICP_PLATFORM_SPACES:
             if self.get_instance_id() == 'openshift' or self.get_instance_id() == 'wml_local':
@@ -120,7 +119,10 @@ class ServiceInstanceNewPlan:
              >>> instance_details = client.service_instance.get_username()
         """
         if self._client.ICP_PLATFORM_SPACES:
-            return self._wml_credentials['username']
+            try:
+                return self._wml_credentials['username']
+            except:
+                raise WMLClientError('`username` missing in wml_credentials.')
         else:
             raise WMLClientError("Not applicable for Cloud")
 
@@ -140,7 +142,10 @@ class ServiceInstanceNewPlan:
              >>> instance_details = client.service_instance.get_password()
         """
         if self._client.ICP_PLATFORM_SPACES:
-            return self._wml_credentials['password']
+            try:
+                return self._wml_credentials['password']
+            except:
+                raise WMLClientError('`password` missing in wml_credentials.')
         else:
             raise WMLClientError("Not applicable for Cloud")
 
@@ -248,15 +253,15 @@ class ServiceInstanceNewPlan:
         return datetime.fromtimestamp(token_expire)
 
     def _is_iam(self):
-        if self._is_iam_token is not None:
-            return self._is_iam_token
+        try:
+            token_parts = self._client.wml_token.split('.')
+            token_padded = token_parts[1] + '=' * (len(token_parts[1]) % 4)
+            token_info = json.loads(base64.b64decode(token_padded).decode('utf-8'))
+            instanceId = token_info.get('instanceId')
 
-        token_parts = self._client.wml_token.split('.')
-        token_padded = token_parts[1] + '=' * (len(token_parts[1]) % 4)
-        token_info = json.loads(base64.b64decode(token_padded).decode('utf-8'))
-        instanceId = token_info.get('instanceId')
-
-        return instanceId
+            return instanceId
+        except:
+            return False
 
     def _get_IAM_token(self):
         if self._client.proceed is True:
@@ -276,9 +281,8 @@ class ServiceInstanceNewPlan:
         if response.status_code == 200:
             token = response.json().get(u'access_token')
             self._expiration_datetime = None
-            self._is_iam_token = None
         else:
-            raise WMLClientError(u'Error during getting IAM Token.', response)
+            raise WMLClientError(u'Error getting IAM Token.', response)
         return token
 
     def _is_token_refresh_possible(self):
@@ -335,10 +339,9 @@ class ServiceInstanceNewPlan:
 
         if response.status_code == 200:
             self._expiration_datetime = None
-            self._is_iam_token = None
             return response.json().get(u'token')
         else:
-            raise WMLClientError(u'Error during refreshing the token.', response)
+            raise WMLClientError(u'Error refreshing the token.', response)
 
     def _get_cpd_token_from_request_new_auth_flow(self):
         bedrock_url = self._href_definitions.get_cpd_bedrock_token_endpoint_href()
@@ -350,11 +353,10 @@ class ServiceInstanceNewPlan:
                                  verify=False)
 
         if response.status_code != 200:
-            raise WMLClientError(u'Error during refreshing the token.', response, logg_messages=False)
+            raise WMLClientError(u'Error refreshing the token.', response, logg_messages=False)
 
         iam_token = response.json()['access_token']
         self._expiration_datetime = datetime.now() + timedelta(seconds=response.json()['expires_in'])
-        self._is_iam_token = True
         # refresh_token = response.json()['refresh_token']
 
         token_url = self._href_definitions.get_cpd_validation_token_endpoint_href()
@@ -368,7 +370,7 @@ class ServiceInstanceNewPlan:
         if response.status_code == 200:
             return response.json()['accessToken']
         else:
-            raise WMLClientError(u'Error during refreshing the token.', response)
+            raise WMLClientError(u'Error refreshing the token.', response)
 
     def _get_cpd_token_from_request(self):
         """
