@@ -201,7 +201,7 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     feature_names = feature_names.tolist()
                 for i in range(dims[1]):
                     training_props["fields"].append({
-                        "name": feature_names[i], "type": type(training_features[0][i].item()).__name__
+                        "name": feature_names[i], "type": type(training_features.item(0, i)).__name__
                     })
 
         elif(isinstance(training_features, list)):
@@ -238,7 +238,7 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     label_column_names = 'l1'
                 elif isinstance(label_column_names, list) or isinstance(label_column_names, np.ndarray):
                     label_column_names = label_column_names[0]
-                training_props["labels"]["fields"].append({"name": label_column_names, "type": type(training_target[0].item()).__name__})
+                training_props["labels"]["fields"].append({"name": label_column_names, "type": type(training_target.item(0)).__name__})
             else:
                 if label_column_names is None:
                     label_column_names = ['l' + str(i) for i in range(dims[1])]
@@ -246,7 +246,7 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     label_column_names = label_column_names.tolist()
                 for i in range(dims[1]):
                     training_props["labels"]["fields"].append({
-                        "name": label_column_names[i], "type": type(training_target[0][i].item()).__name__
+                        "name": label_column_names[i], "type": type(training_target.item(0, i)).__name__
                     })
         elif(isinstance(training_target, list)):
             if not isinstance(training_target[0], list):
