@@ -97,7 +97,7 @@ class Migrationv4GACloud(WMLResource):
             with_validation=True,
             client=self._client)
 
-        href = self._href_definitions.v4ga_cloud_migration_href()
+        href = self._client.service_instance._href_definitions.v4ga_cloud_migration_href()
 
         start_response = requests.post(href,
                                        headers=self._client._get_headers(),
@@ -183,7 +183,7 @@ class Migrationv4GACloud(WMLResource):
         if space_id is None and project_id is None:
             raise WMLClientError("Its mandatory to provide space_id or project_id")
 
-        href = self._href_definitions.v4ga_cloud_migration_id_href(migration_id)
+        href = self._client.service_instance._href_definitions.v4ga_cloud_migration_id_href(migration_id)
 
         params = {}
 
@@ -238,7 +238,7 @@ class Migrationv4GACloud(WMLResource):
         if space_id is None and project_id is None:
             raise WMLClientError("Its mandatory to provide space_id or project_id")
 
-        href = self._href_definitions.v4ga_cloud_migration_id_href(migration_id)
+        href = self._client.service_instance._href_definitions.v4ga_cloud_migration_id_href(migration_id)
 
         params = {'hard_delete': True}
 
@@ -305,7 +305,7 @@ class Migrationv4GACloud(WMLResource):
         else:
             query_params.update({'project_id': project_id})
 
-        href = self._href_definitions.v4ga_cloud_migration_href()
+        href = self._client.service_instance._href_definitions.v4ga_cloud_migration_href()
 
         return self._get_artifact_details(href, migration_id, limit, 'migration', query_params=query_params)
 
