@@ -71,19 +71,19 @@ class SwSpec(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self,sw_spec_uid=None):
         """
-            Get software specification details.
+            Get software specification details. If no sw_spec_id is passed, details for all software specifications will be returned.
 
             **Parameters**
 
             .. important::
-                #. **sw_spec_details**:  Metadata of the stored sw_spec\n
-                   **type**: dict\n
+                **returns**: sw_spec UID\n
+                **return type**: str
 
             **Output**
 
             .. important::
-                **returns**: sw_spec UID\n
-                **return type**: str
+                #. **sw_spec_details**:  Metadata of the stored sw_spec\n
+                   **type**: dict\n
 
             **Example**
 
@@ -93,25 +93,52 @@ class SwSpec(WMLResource):
         if self._client.WSD_20:
             raise WMLClientError(u'get_details API is not supported in Watson Studio Desktop.')
 
-        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
+        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, False)
 
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
-                                    params=self._client._params(skip_space_project_chk=True),
-                                    headers=self._client._get_headers())
-        else:
-            if self._client.ICP_PLATFORM_SPACES:
+        if sw_spec_uid:
+            if not self._ICP:
                 response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                                         params=self._client._params(skip_space_project_chk=True),
-                                        headers=self._client._get_headers(), verify=False)
+                                        headers=self._client._get_headers())
             else:
-                response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
-                                          headers=self._client._get_headers(), verify=False)
+                if self._client.ICP_PLATFORM_SPACES:
+                    response = requests.get(
+                        self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
+                        params=self._client._params(skip_space_project_chk=True),
+                        headers=self._client._get_headers(), verify=False)
+                else:
+                    response = requests.get(
+                        self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
+                        params=self._client._params(),
+                        headers=self._client._get_headers(), verify=False)
 
-        if response.status_code == 200:
-            return self._get_required_element_from_response(self._handle_response(200, u'get sw spec details', response))
+            if response.status_code == 200:
+                return self._get_required_element_from_response(
+                    self._handle_response(200, u'get sw spec details', response))
+            else:
+                return self._handle_response(200, u'get sw spec details', response)
         else:
-            return self._handle_response(200, u'get sw spec details', response)
+            if not self._ICP:
+                response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
+                                        params=self._client._params(skip_space_project_chk=True),
+                                        headers=self._client._get_headers())
+            else:
+                if self._client.ICP_PLATFORM_SPACES:
+                    response = requests.get(
+                        self._client.service_instance._href_definitions.get_sw_specs_href(),
+                        params=self._client._params(skip_space_project_chk=True),
+                        headers=self._client._get_headers(), verify=False)
+                else:
+                    response = requests.get(
+                        self._client.service_instance._href_definitions.get_sw_specs_href(),
+                        params=self._client._params(),
+                        headers=self._client._get_headers(), verify=False)
+
+            if response.status_code == 200:
+                return {'resources': [self._get_required_element_from_response(x)
+                                      for x in self._handle_response(200, u'get sw specs details', response)['resources']]}
+            else:
+                return self._handle_response(200, u'get sw specs details', response)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
