@@ -168,6 +168,9 @@ class AbstractTestAutoAIRemote(abc.ABC):
         print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop(['species'], axis=1).values[:5])
         print(predictions)
