@@ -107,6 +107,8 @@ class TestAutoAIRemote(unittest.TestCase):
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
         cls.project_id = cls.wml_credentials.get('project_id')
 
+        cls.wml_client.set.default_project(cls.project_id)
+
 
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
@@ -116,10 +118,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                                  cos_resource_instance_id=self.cos_resource_instance_id)
 
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
+
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP:
@@ -236,9 +235,6 @@ class TestAutoAIRemote(unittest.TestCase):
         # print(parameters)
         self.assertIsNotNone(parameters)
 
-    def test_06c_get_metrics(self):
-        self.wml_client.training.get_metrics(self.run_id)
-
     def test_07_get_summary(self):
 
         print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
@@ -291,6 +287,9 @@ class TestAutoAIRemote(unittest.TestCase):
         pipeline = self.remote_auto_pipelines.get_pipeline()
         print(f"Fetched pipeline type: {type(pipeline)}")
 
+    def test_09b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     #################################
     #      DEPLOYMENT SECTION       #
     #################################
