@@ -136,8 +136,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_01_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                             project_id=self.project_id,
-                                             space_id=self.space_id)
+                                             project_id=self.project_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -259,6 +258,9 @@ class TestAutoAIRemote(unittest.TestCase):
         print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
@@ -328,7 +330,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_21_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
+                                              target_wml_credentials=self.wml_credentials,
+                                              target_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
