@@ -120,6 +120,7 @@ class TestAutoAIRemote(unittest.TestCase):
             # --- end note
 
         cls.project_id = cls.wml_credentials.get('project_id')
+        cls.wml_client.set.default_project(cls.project_id)
 
     def _check_optimizer_parameters(self, parameters):
         # check_pipeline_parameters:
@@ -138,10 +139,6 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP or self.wml_client.WSD:
@@ -266,9 +263,6 @@ class TestAutoAIRemote(unittest.TestCase):
         # print(parameters)
         self.assertIsNotNone(parameters)
 
-    def test_07b_get_metrics(self):
-        self.wml_client.training.get_metrics(self.run_id)
-
     def test_08_get_summary(self):
 
         print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
@@ -319,6 +313,9 @@ class TestAutoAIRemote(unittest.TestCase):
         pipeline = self.remote_auto_pipelines.get_pipeline()
         print(f"Fetched pipeline type: {type(pipeline)}")
 
+    def test_10b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_11_waiting_for_fitted_completed(self):
         while self.remote_auto_pipelines.get_run_status() == 'running':
             time.sleep(10)
@@ -438,14 +435,10 @@ class TestAutoAIRemote(unittest.TestCase):
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
-                                                   target_wml_credentials=self.wml_credentials,
-                                                   target_space_id=self.space_id)
-        else:
-            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                                   source_space_id=self.space_id)
+        TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                               source_project_id=self.project_id,
+                                               target_wml_credentials=self.wml_credentials,
+                                               target_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
