@@ -19,6 +19,7 @@ from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, space_cleanup
 
 
+@unittest.skipIf(is_cp4d(), "Excel files not supported on CPD 4.0 an low")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test covers:
@@ -225,6 +226,9 @@ class TestAutoAIRemote(unittest.TestCase):
         parameters = self.remote_auto_pipelines.get_run_details()
         print(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop([self.target_column], axis=1).values[:5])
         print(predictions)
