@@ -88,14 +88,6 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         if not cls.wml_client.ICP:
             cls.cos_credentials = get_cos_credentials()
@@ -237,6 +229,9 @@ class TestAutoAIRemote(unittest.TestCase):
         parameters = self.remote_auto_pipelines.get_run_details()
         print(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop(['species'], axis=1).values[:5])
         print(predictions)
