@@ -177,6 +177,9 @@ class TestAutoAIRemote(unittest.TestCase):
         parameters = self.remote_auto_pipelines.get_run_details()
         print(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.train_data.drop(['species'], axis=1).values[:5])
         print(predictions)
