@@ -13,6 +13,7 @@ from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
 from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
+from ibm_watson_machine_learning.utils import WMLClientError
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
@@ -107,20 +108,18 @@ class TestOBMOnly(unittest.TestCase):
 
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
+        cls.wml_client.set.default_project(cls.project_id)
+
+    # @print_test_separators
+    # def test_00a_space_cleanup(self):
+    #     space_cleanup(self.wml_client,
+    #                   get_space_id(self.wml_client, self.space_name,
+    #                                cos_resource_instance_id=self.cos_resource_instance_id),
+    #                   days_old=7)
+    #     TestOBMOnly.space_id = get_space_id(self.wml_client, self.space_name,
+    #                                  cos_resource_instance_id=self.cos_resource_instance_id)
 
-    @print_test_separators
-    def test_00a_space_cleanup(self):
-        space_cleanup(self.wml_client,
-                      get_space_id(self.wml_client, self.space_name,
-                                   cos_resource_instance_id=self.cos_resource_instance_id),
-                      days_old=7)
-        TestOBMOnly.space_id = get_space_id(self.wml_client, self.space_name,
-                                     cos_resource_instance_id=self.cos_resource_instance_id)
 
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -259,8 +258,7 @@ class TestOBMOnly(unittest.TestCase):
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
         TestOBMOnly.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                        project_id=self.project_id,
-                                        space_id=self.space_id)
+                                        project_id=self.project_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -480,7 +478,8 @@ class TestOBMOnly(unittest.TestCase):
         self.assertIsNotNone(parameters)
 
     def test_14b_get_metrics(self):
-        self.wml_client.training.get_metrics(self.run_id)
+        with self.assertRaises(WMLClientError, msg="No metrics available for obm only"):
+            self.wml_client.training.get_metrics(self.run_id)
 
     @print_test_separators
     def test_15__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
