@@ -123,6 +123,8 @@ class TestOBMAndKB(unittest.TestCase):
 
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
+        cls.wml_client.set.default_project(cls.project_id)
+
 
     @print_test_separators
     def test_00a_space_cleanup(self):
@@ -133,10 +135,6 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.space_id = get_space_id(self.wml_client, self.space_name,
                                              cos_resource_instance_id=self.cos_resource_instance_id)
 
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -282,8 +280,7 @@ class TestOBMAndKB(unittest.TestCase):
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
         TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                         project_id=self.project_id,
-                                         space_id=self.space_id)
+                                         project_id=self.project_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -699,18 +696,11 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_26_batch_deployment_setup_and_preparation(self):
-        if is_cp4d():
-            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials.copy(),
-                                         target_space_id=self.space_id)
-        else:
-            TestOBMAndKB.service = Batch(self.wml_credentials,
-                                         source_space_id=self.space_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
+        TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                     source_project_id=self.project_id,
+                                     target_wml_credentials=self.wml_credentials.copy(),
+                                     target_space_id=self.space_id)
 
-        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_27_deploy__deploy_best_computed_pipeline_from_autoai_on_wml(self):
@@ -719,7 +709,6 @@ class TestOBMAndKB(unittest.TestCase):
             model=self.pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_28_score_deployed_model(self):
@@ -843,19 +832,11 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_35_batch_deployment_setup_and_preparation_notebook(self):
-        if is_cp4d():
-            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials.copy(),
-                                         target_space_id=self.space_id)
-        else:
-            TestOBMAndKB.service = Batch(self.wml_credentials,
-                                         source_space_id=self.space_id,
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
+        TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                     source_project_id=self.project_id,
+                                     target_wml_credentials=self.wml_credentials.copy(),
+                                     target_space_id=self.space_id)
 
-        self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_36__deploy__deploy_best_computed_pipeline_from_autoai_on_wml_notebook(self):
@@ -864,7 +845,6 @@ class TestOBMAndKB(unittest.TestCase):
             model=self.pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
 
     @print_test_separators
     def test_37a_score_deployed_model_notebook(self):
