@@ -114,7 +114,7 @@ class TestOBMAndKB(unittest.TestCase):
             cls.cos_resource_instance_id = cls.cos_credentials.get('resource_instance_id')
 
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
-        cls.project_id = cls.wml_credentials.get('project_id')
+        # cls.project_id = cls.wml_credentials.get('project_id')
 
     @print_test_separators
     def test_00a_space_cleanup(self):
@@ -125,10 +125,7 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
 
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
+        self.wml_client.set.default_space(self.space_id)
 
     @print_test_separators
     def test_00b_prepare_COS_instance(self):
@@ -264,8 +261,7 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_04_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         print("Initializing AutoAI experiment...")
-        TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                         project_id=self.project_id,
+        TestOBMAndKB.experiment = AutoAI(wml_credentials=self.wml_credentials,
                                          space_id=self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
@@ -663,17 +659,10 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_26_batch_deployment_setup_and_preparation(self):
-        if is_cp4d():
-            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials,
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
-
-        else:
-            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials,
-                                         source_space_id=self.space_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
+        TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials,
+                                     source_space_id=self.space_id,
+                                     target_wml_credentials=self.wml_credentials,
+                                     target_space_id=self.space_id)
 
         self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
@@ -684,8 +673,6 @@ class TestOBMAndKB(unittest.TestCase):
             model="Pipeline_3",
             deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
-
     @print_test_separators
     def test_28_score_deployed_model(self):
         if is_cp4d():
@@ -721,7 +708,6 @@ class TestOBMAndKB(unittest.TestCase):
         self.service.delete()
         self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
-        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
     #################################
     #      NOTEBOOK SECTION       #
@@ -798,17 +784,10 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_35_batch_deployment_setup_and_preparation_notebook(self):
-        if is_cp4d():
-            TestOBMAndKB.service = Batch(self.wml_credentials,
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
-        else:
-            TestOBMAndKB.service = Batch(self.wml_credentials,
-                                         source_space_id=self.space_id,
-                                         source_project_id=self.project_id,
-                                         target_wml_credentials=self.wml_credentials,
-                                         target_space_id=self.space_id)
+        TestOBMAndKB.service = Batch(self.wml_credentials,
+                                     source_space_id=self.space_id,
+                                     target_wml_credentials=self.wml_credentials,
+                                     target_space_id=self.space_id)
 
         self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
@@ -820,8 +799,6 @@ class TestOBMAndKB(unittest.TestCase):
             model=self.pipeline_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
-        self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
-
     @print_test_separators
     @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_37a_score_deployed_model_notebook(self):
@@ -881,7 +858,6 @@ class TestOBMAndKB(unittest.TestCase):
         self.service.delete()
         self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(self.service.asset_id)
-        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 if __name__ == '__main__':
     unittest.main()
