@@ -227,6 +227,9 @@ class TestAutoAIRemote(unittest.TestCase):
         print(parameters)
         self.assertIsNotNone(parameters)
 
+    def test_08b_get_metrics(self):
+        self.wml_client.training.get_metrics(self.run_id)
+
     def test_09_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
