@@ -16,8 +16,11 @@ from enum import Enum
 
 __all__ = [
     "ClassificationAlgorithms",
+    "ClassificationAlgorithmsCP4D",
     "RegressionAlgorithms",
+    "RegressionAlgorithmsCP4D",
     "ForecastingAlgorithms",
+    "ForecastingAlgorithmsCP4D",
     "PredictionType",
     "Metrics",
     "Transformers",
@@ -33,7 +36,22 @@ __all__ = [
 
 
 class ClassificationAlgorithms(Enum):
-    """Classification algorithms that AutoAI could use."""
+    """Classification algorithms that AutoAI could use for IBM Cloud."""
+    EX_TREES = "ExtraTreesClassifierEstimator"
+    GB = "GradientBoostingClassifierEstimator"
+    LGBM = "LGBMClassifierEstimator"
+    LR = "LogisticRegressionEstimator"
+    RF = "RandomForestClassifierEstimator"
+    XGB = "XGBClassifierEstimator"
+    DT = "DecisionTreeClassifierEstimator"
+    SnapDT = "SnapDecisionTreeClassifier"
+    SnapRF = "SnapRandomForestClassifier"
+    SnapSVM = "SnapSVMClassifier",
+    SnapLR = "SnapLogisticRegression"
+
+
+class ClassificationAlgorithmsCP4D(Enum):
+    """Classification algorithms that AutoAI could use for IBM Cloud Pak® for Data(CP4D)."""
     EX_TREES = "ExtraTreesClassifierEstimator"
     GB = "GradientBoostingClassifierEstimator"
     LGBM = "LGBMClassifierEstimator"
@@ -44,7 +62,22 @@ class ClassificationAlgorithms(Enum):
 
 
 class RegressionAlgorithms(Enum):
-    """Regression algorithms that AutoAI could use."""
+    """Regression algorithms that AutoAI could use for IBM Cloud."""
+    RF = "RandomForestRegressorEstimator"
+    RIDGE = "RidgeEstimator"
+    EX_TREES = "ExtraTreesRegressorEstimator"
+    GB = "GradientBoostingRegressorEstimator"
+    LR = "LinearRegressionEstimator"
+    XGB = "XGBRegressorEstimator"
+    LGBM = "LGBMRegressorEstimator"
+    DT = "DecisionTreeRegressorEstimator"
+    SnapDT = "SnapDecisionTreeRegressor"
+    SnapRF = "SnapRandomForestRegressor"
+    SnapBM = "SnapBoostingMachineRegressor"
+
+
+class RegressionAlgorithmsCP4D(Enum):
+    """Regression algorithms that AutoAI could use for IBM Cloud Pak® for Data(CP4D)."""
     RF = "RandomForestRegressorEstimator"
     RIDGE = "RidgeEstimator"
     EX_TREES = "ExtraTreesRegressorEstimator"
@@ -55,8 +88,19 @@ class RegressionAlgorithms(Enum):
     DT = "DecisionTreeRegressorEstimator"
 
 
+class ForecastingAlgorithmsCP4D(Enum):
+    """Forecasting algorithms that AutoAI could use for IBM Cloud."""
+    LR = "LinearRegression"
+    ENSEMBLER = "Ensembler"
+    ARIMA = "ARIMA"
+    HW = "HoltWinters"
+    BATS = "BATS"
+    RF = "RandomForest"
+    SVM = "SVM"
+
+
 class ForecastingAlgorithms(Enum):
-    """Forecasting algorithms that AutoAI could use."""
+    """Forecasting algorithms that AutoAI could use for IBM Cloud Pak® for Data(CP4D)."""
     LR = "LinearRegression"
     ENSEMBLER = "Ensembler"
     ARIMA = "ARIMA"
@@ -101,6 +145,7 @@ class Metrics:
 
     """
     ACCURACY_SCORE = "accuracy"
+    # ACCURACY_AND_DISPARATE_IMPACT_SCORE = "accuracy_and_disparate_impact" TODO: uncomment to add fairness support
     AVERAGE_PRECISION_SCORE = "average_precision"
     F1_SCORE = "f1"
     LOG_LOSS = "neg_log_loss"
@@ -126,6 +171,7 @@ class Metrics:
     ROOT_MEAN_SQUARED_ERROR = "neg_root_mean_squared_error"
     ROOT_MEAN_SQUARED_LOG_ERROR = "neg_root_mean_squared_log_error"
     R2_SCORE = "r2"
+    # R2_AND_DISPARATE_IMPACT_SCORE = "r2_and_disparate_impact" TODO: uncomment to add fairness support
 
 
 class Transformers:
