@@ -66,7 +66,8 @@ import pkg_resources
 import requests
 from packaging import version
 
-from .enums import (RegressionAlgorithms, ClassificationAlgorithms, ForecastingAlgorithms, Transformers,
+from .enums import (RegressionAlgorithms, RegressionAlgorithmsCP4D, ClassificationAlgorithms,
+                    ClassificationAlgorithmsCP4D, ForecastingAlgorithms, ForecastingAlgorithmsCP4D, Transformers,
                     Metrics, TShirtSize, PredictionType)
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
@@ -133,6 +134,8 @@ def fetch_pipelines(run_params: dict,
         """
         Automate check all pipeline nodes to find xgboost or lightgbm dependency.
         """
+        snapml_estimators = [i.value for i in ClassificationAlgorithms if 'Snap' in i.value] + [
+            i.value for i in RegressionAlgorithms if 'Snap' in i.value]
         xgboost_estimators = ['XGBClassifierEstimator', 'XGBRegressorEstimator', 'XGBClassifier', 'XGBRegressor']
         lightgbm_estimators = ['LGBMClassifierEstimator', 'LGBMRegressorEstimator', 'LGBMClassifier', 'LGBMRegressor']
 
@@ -144,6 +147,8 @@ def fetch_pipelines(run_params: dict,
         elif estimator_name in lightgbm_estimators:
             check_lale = check_dependencies_versions(request_json, wml_client, 'lightgbm')
 
+        elif estimator_name in snapml_estimators:
+            check_lale = check_dependencies_versions(request_json, wml_client, 'snapml')
         else:
             check_lale = check_dependencies_versions(request_json, wml_client, None)
 
@@ -1066,11 +1071,13 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                     installed_module_version = pkg_resources.get_distribution(package['name']).version
 
                 # workaround for autai-libs and numpy versions in SW spec
-                if package['name'] == 'autoai-libs' or package['name'] == 'numpy' or package['name'] == 'lale':
+                if package['name'] == 'autoai-libs' or package['name'] == 'numpy' \
+                        or package['name'] == 'lale' or package['name'] == 'snapml':
                     if version.parse(installed_module_version) < version.parse(package['version']):
-                        # we should produce different error for lale as only 2 major numbers are significant
-                        if package['name'] == 'lale' and len(package['version'].split('.')) == 3:
-                            _version = package['version'].split('.')
+                        # we should produce different error for lale and snap_ml as only 2 major numbers are significant
+                        packages_less_strict_error_list = ['lale', 'snapml'],
+                        if package['name'] in packages_less_strict_error_list and len(package['version'].split('.')) >= 3:
+                            _version = package['version'].split('.')[:2]  # take only 3 major version number
                             _version[-1] = 'x'
                             package['version'] = '.'.join(_version)
 
@@ -1143,13 +1150,15 @@ def prepare_cos_client(
 
     if training_result_reference is not None:
         if (isinstance(training_result_reference.connection, S3Connection) or
-                training_result_reference._check_if_connection_asset_is_s3()):
+                (os.environ.get('USER_ACCESS_TOKEN') is None and
+                 training_result_reference._check_if_connection_asset_is_s3())):
             cos_client_results = (training_result_reference,
                                   differentiate_between_credentials(connection=training_result_reference.connection))
 
     if training_data_references is not None:
         for reference in training_data_references:
-            if isinstance(reference.connection, S3Connection) or reference._check_if_connection_asset_is_s3():
+            if (isinstance(reference.connection, S3Connection) or
+                    (os.environ.get('USER_ACCESS_TOKEN') is None and reference._check_if_connection_asset_is_s3())):
                 data_cos_clients.append((reference,
                                          differentiate_between_credentials(connection=reference.connection)))
 
@@ -1482,7 +1491,7 @@ def validate_additional_params_for_optimizer(params):
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
         'enabled_feature_engineering_as_json', 'fairness_info', 'text_processing', 'word2vec_feature_number',
-        '_enable_snapml_estimators'
+        '_enable_snapml_estimators','return_holdout_indices', 'retrain_pipelines_on_holdout_data'
     ]
 
     for k in params:
@@ -1578,7 +1587,8 @@ def validate_optimizer_enum_values(
                                                  ForecastingAlgorithms]],
         cognito_transform_names: List[Transformers],
         scoring: str,
-        t_shirt_size: str) -> None:
+        t_shirt_size: str,
+        is_cpd = False) -> None:
     """
     Validate if passed optimizer variables takes values from defined enums.
 
@@ -1596,17 +1606,27 @@ def validate_optimizer_enum_values(
         Type of the metric to optimize with.
     t_shirt_size: str
         The size of the remote AutoAI POD instance.
+    is_cpd: bool
+        True if run on CP4D environment. CP4D estimators will be used to check.
 
     Raises
     ------
     InvalidSequenceValue, If element is not from enum class values.
     """
-    if prediction_type == PredictionType.REGRESSION:
-        estimators_enum = RegressionAlgorithms
-    elif prediction_type == PredictionType.FORECASTING:
-        estimators_enum = ForecastingAlgorithms
+    if is_cpd:
+        if prediction_type == PredictionType.REGRESSION:
+            estimators_enum = RegressionAlgorithmsCP4D
+        elif prediction_type == PredictionType.FORECASTING:
+            estimators_enum = ForecastingAlgorithmsCP4D
+        else:
+            estimators_enum = ClassificationAlgorithmsCP4D
     else:
-        estimators_enum = ClassificationAlgorithms
+        if prediction_type == PredictionType.REGRESSION:
+            estimators_enum = RegressionAlgorithms
+        elif prediction_type == PredictionType.FORECASTING:
+            estimators_enum = ForecastingAlgorithms
+        else:
+            estimators_enum = ClassificationAlgorithms
     for (sequence, enum_class) in (
             ([prediction_type], PredictionType),
             (daub_include_only_estimators, estimators_enum),
