@@ -178,6 +178,9 @@ class WMLResource:
             else:
                 params = query_params
 
+            if 'userfs' in params:
+                params.pop('userfs')
+
             url = base_url + u'/' + uid
 
             if not self._ICP and not self._client.WSD:
