@@ -300,7 +300,7 @@ class TensorFlowFLModel(FLModel):
         """
         if filename is None:
             file = self.model_name if self.model_name else self.model_type
-            filename = '{}_{}'.format(file, time.time())
+            filename = '{}'.format(file)
 
         full_path = super().get_model_absolute_path(filename)
         self.model.save(full_path)
