@@ -49,6 +49,8 @@ class Party:
         :type config_dict: `dict`
         :return None
         """
+        self.isCloud = False
+        self.isXGB = False
         log_level = kwargs.get('log_level', 'INFO')
         configure_logging_from_file(log_level=log_level)
 
@@ -59,7 +61,20 @@ class Party:
 
         config_dict['connection']['name'] = 'WSConnection'
         config_dict['connection']['path'] = 'ibmfl.connection.websockets_connection'
+
+        if config_dict.get('aggregator', None) is not None:
+            if config_dict.get('aggregator').get('ip', None) is not None:
+                if "cloud.ibm.com" in config_dict.get('aggregator').get('ip'):
+                    self.isCloud = True       
+                    if config_dict.get('local_training', None) is not None:
+                        if config_dict.get('local_training').get('path', None) is not None:
+                            if "ibmfl.party.training.xgboost_local_training_handler" in config_dict.get('local_training').get('path'):
+                                self.isXGB = True
+                                config_dict['local_training']['path'] = 'ibmfl.party.training.v2.xgboost_local_training_handler'
         
+        logger.info("IS CLOUD = " + str(self.isCloud))
+        logger.info("IS XGB = " + str(self.isXGB))
+
         cls_config = fl_config.get_cls_by_config(config_dict)
 
         self.party_config = cls_config
@@ -135,11 +150,21 @@ class Party:
         cls_config = self.party_config
         model_config = cls_config.get('model')
         lt_config = cls_config.get('local_training')
+
         try:
             
             # Read and create model (optional field)
             # In some cases aggregator doesn't need to load the model:
             model_cls_ref = model_config.get('cls_ref')
+            if self.isCloud and self.isXGB:
+                previous_cls_ref = fl_config.get_class_by_name("ibmfl.model.xgb_fl_model", "XGBClassifierFLModel")
+                if model_cls_ref == previous_cls_ref:
+                    model_cls_ref = fl_config.get_class_by_name("ibmfl.model.v2.xgb_fl_model", "XGBClassifierFLModel")
+                else:
+                    previous_cls_ref = fl_config.get_class_by_name("ibmfl.model.xgb_fl_model", "XGBRegressorFLModel")
+                    if model_cls_ref == previous_cls_ref:
+                        model_cls_ref = fl_config.get_class_by_name("ibmfl.model.v2.xgb_fl_model", "XGBRegressorFLModel")
+
             spec = model_config.get('spec')
             self.fl_model = model_cls_ref('', spec)
 
@@ -186,6 +211,8 @@ class Party:
                     returnValue = False
             else:
                 logger.error('Registration Failed: Failure status from aggregator')
+                if response is not None:
+                    logger.error(response.get_data().get('detail', "No Detail Provided"))
         except Exception as ex:
             logger.error("Error occurred during registration" + str(ex))
 
@@ -237,6 +264,8 @@ class Party:
                 logger.info('Listening for commands from Aggregator')
                 self.is_running = True
                 self.initialize_model_config()
+            else:
+                self.stop_connection()
         else:
             logger.info('Party already running.')
 
@@ -318,7 +347,7 @@ if __name__ == '__main__':
     parser.add_argument('-s', '--self_signed_cert', help='flag for self-signed certificate', action='store_true')
     parser.add_argument('-i', '--interactive',
                         help='run interactively', action='store_true')
-    parser.add_argument('log_level', type=str, default="INFO", required=False,
+    parser.add_argument('-l', '--log_level', type=str, default="INFO", required=False,
                         help='log_level should be a value from [DEBUG, INFO, WARNING, ERROR, CRITICAL]')
     args = parser.parse_args()
 
